@@ -2,9 +2,8 @@ package chezmoi
 
 import (
 	"io/fs"
-	"os/exec"
 
-	vfs "github.com/twpayne/go-vfs/v4"
+	vfs "github.com/twpayne/go-vfs/v5"
 )
 
 // A ReadOnlySystem is a system that may only be read from.
@@ -25,16 +24,6 @@ func (s *ReadOnlySystem) Glob(pattern string) ([]string, error) {
 	return s.system.Glob(pattern)
 }
 
-// IdempotentCmdCombinedOutput implements System.IdempotentCmdCombinedOutput.
-func (s *ReadOnlySystem) IdempotentCmdCombinedOutput(cmd *exec.Cmd) ([]byte, error) {
-	return s.system.IdempotentCmdCombinedOutput(cmd)
-}
-
-// IdempotentCmdOutput implements System.IdempotentCmdOutput.
-func (s *ReadOnlySystem) IdempotentCmdOutput(cmd *exec.Cmd) ([]byte, error) {
-	return s.system.IdempotentCmdOutput(cmd)
-}
-
 // Lstat implements System.Lstat.
 func (s *ReadOnlySystem) Lstat(filename AbsPath) (fs.FileInfo, error) {
 	return s.system.Lstat(filename)
@@ -60,11 +49,6 @@ func (s *ReadOnlySystem) Readlink(name AbsPath) (string, error) {
 	return s.system.Readlink(name)
 }
 
-// RunIdempotentCmd implements System.RunIdempotentCmd.
-func (s *ReadOnlySystem) RunIdempotentCmd(cmd *exec.Cmd) error {
-	return s.system.RunIdempotentCmd(cmd)
-}
-
 // Stat implements System.Stat.
 func (s *ReadOnlySystem) Stat(name AbsPath) (fs.FileInfo, error) {
 	return s.system.Stat(name)
